<?php
namespace Bushelpowered\Api\Trade\Offers\V1\Model;
        
class OrderStandard 
{
    /** @var string $id The trade order id*/
    public string $id;
    /** @var string $companySlug The companySlug (plus tenantId will identify order*/
    public string $companySlug;
    /** @var string $contractId The Bushel Account*/
    public string $contractId;
    /** @var int $quantity The quantity of the order*/
    public int $quantity;
    /** @var float $price The price associated to the order. Decimal*/
    public float $price;
    /** @var float $basisPrice The basis price of the order. Decimal*/
    public float $basisPrice;
    /** @var float $futuresPrice The futures price of the order. Decimal*/
    public float $futuresPrice;
    /** @var null|string $comments Comments associated*/
    public ?string $comments = null;
    /** @var string $bushelAccount The Bushel Account*/
    public string $bushelAccount;
    /** @var string $erpAccount The account at the company's associated ERP*/
    public string $erpAccount;
    /** @var string $erpLocation The ERP's location*/
    public string $erpLocation;
    /** @var string $erpCommodity The ERP's commodity*/
    public string $erpCommodity;
    /** @var string $orderCreatedAt The datetime the order was created of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $orderCreatedAt;
    /** @var string $expiresAt The datetime the order will expire of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $expiresAt;
    /** @var bool $forceFill Industry term for ‘fill at whatever price.’ String.*/
    public bool $forceFill;
    /** @var bool $careOrder Industry term for ‘don't fill until manually approved’. String.*/
    public bool $careOrder;
    /** @var string $contractSymbol The symbol of the contract*/
    public string $contractSymbol;
    /** @var int $pricingType CQG values; 0=cash, 1=flat, 2=basis, 3=hedge*/
    public int $pricingType;
    /** @var string $unitOfMeasure The measurement used in this order, ie. ‘bu’, etc.*/
    public string $unitOfMeasure;
    /** @var string $commodityCode CQG calls this Instrument Group Name*/
    public string $commodityCode;
    /** @var string $commodityName The commodity name*/
    public string $commodityName;
    /** @var string $locationName The location name*/
    public string $locationName;
    /** @var string $exchangeAbbreviation The abbreviation for the exchange.*/
    public string $exchangeAbbreviation;
    /** @var string $futuresSymbol The future's symbol*/
    public string $futuresSymbol;
    /** @var string $deliveryStart The start datetime for the delivery of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $deliveryStart;
    /** @var string $deliveryEnd The end datetime for the delivery of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $deliveryEnd;
    /** @var string $chainOrderId CQG number, associations to other order*/
    public string $chainOrderId;
    /** @var float $remainingQty The remaining qty on the order*/
    public float $remainingQty;
    /** @var float $filledPrice Represents the price the order filled at*/
    public float $filledPrice;
    /** @var bool $orderStatusIsNew Indicates whether the order status is different from the previous value*/
    public bool $orderStatusIsNew;
    /** @var string $userIdpId The user idp id for the order*/
    public string $userIdpId;

    /**
     * @param  string  $id The trade order id
     * @param  string  $companySlug The companySlug (plus tenantId will identify order
     * @param  string  $contractId The Bushel Account
     * @param  int  $quantity The quantity of the order
     * @param  float  $price The price associated to the order. Decimal
     * @param  float  $basisPrice The basis price of the order. Decimal
     * @param  float  $futuresPrice The futures price of the order. Decimal
     * @param  null|string  $comments Comments associated
     * @param  string  $bushelAccount The Bushel Account
     * @param  string  $erpAccount The account at the company's associated ERP
     * @param  string  $erpLocation The ERP's location
     * @param  string  $erpCommodity The ERP's commodity
     * @param  string  $orderCreatedAt The datetime the order was created of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $expiresAt The datetime the order will expire of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  bool  $forceFill Industry term for ‘fill at whatever price.’ String.
     * @param  bool  $careOrder Industry term for ‘don't fill until manually approved’. String.
     * @param  string  $contractSymbol The symbol of the contract
     * @param  int  $pricingType CQG values; 0=cash, 1=flat, 2=basis, 3=hedge
     * @param  string  $unitOfMeasure The measurement used in this order, ie. ‘bu’, etc.
     * @param  string  $commodityCode CQG calls this Instrument Group Name
     * @param  string  $commodityName The commodity name
     * @param  string  $locationName The location name
     * @param  string  $exchangeAbbreviation The abbreviation for the exchange.
     * @param  string  $futuresSymbol The future's symbol
     * @param  string  $deliveryStart The start datetime for the delivery of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $deliveryEnd The end datetime for the delivery of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $chainOrderId CQG number, associations to other order
     * @param  float  $remainingQty The remaining qty on the order
     * @param  float  $filledPrice Represents the price the order filled at
     * @param  bool  $orderStatusIsNew Indicates whether the order status is different from the previous value
     * @param  string  $userIdpId The user idp id for the order
     */
    public function __construct(string $id, string $companySlug, string $contractId, int $quantity, float $price, float $basisPrice, float $futuresPrice, ?string $comments, string $bushelAccount, string $erpAccount, string $erpLocation, string $erpCommodity, string $orderCreatedAt, string $expiresAt, bool $forceFill, bool $careOrder, string $contractSymbol, int $pricingType, string $unitOfMeasure, string $commodityCode, string $commodityName, string $locationName, string $exchangeAbbreviation, string $futuresSymbol, string $deliveryStart, string $deliveryEnd, string $chainOrderId, float $remainingQty, float $filledPrice, bool $orderStatusIsNew, string $userIdpId)
    {
        $this->id = $id;
        $this->companySlug = $companySlug;
        $this->contractId = $contractId;
        $this->quantity = $quantity;
        $this->price = $price;
        $this->basisPrice = $basisPrice;
        $this->futuresPrice = $futuresPrice;
        $this->comments = $comments;
        $this->bushelAccount = $bushelAccount;
        $this->erpAccount = $erpAccount;
        $this->erpLocation = $erpLocation;
        $this->erpCommodity = $erpCommodity;
        $this->orderCreatedAt = $orderCreatedAt;
        $this->expiresAt = $expiresAt;
        $this->forceFill = $forceFill;
        $this->careOrder = $careOrder;
        $this->contractSymbol = $contractSymbol;
        $this->pricingType = $pricingType;
        $this->unitOfMeasure = $unitOfMeasure;
        $this->commodityCode = $commodityCode;
        $this->commodityName = $commodityName;
        $this->locationName = $locationName;
        $this->exchangeAbbreviation = $exchangeAbbreviation;
        $this->futuresSymbol = $futuresSymbol;
        $this->deliveryStart = $deliveryStart;
        $this->deliveryEnd = $deliveryEnd;
        $this->chainOrderId = $chainOrderId;
        $this->remainingQty = $remainingQty;
        $this->filledPrice = $filledPrice;
        $this->orderStatusIsNew = $orderStatusIsNew;
        $this->userIdpId = $userIdpId;
    }
    

}